IconlyBroken class

A collection of broken styled icons from the Iconly pack.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

activity → const IconData
The activity icon.
addUser → const IconData
The add user icon.
arrowDown → const IconData
The arrow down icon.
arrowDown2 → const IconData
The arrow down 2 icon.
arrowDown3 → const IconData
The arrow down 3 icon.
arrowDownCircle → const IconData
The arrow down circle icon.
arrowDownSquare → const IconData
The arrow down square icon.
arrowLeft → const IconData
The arrow left icon.
arrowLeft2 → const IconData
The arrow left 2 icon.
arrowLeft3 → const IconData
The arrow left 3 icon.
arrowLeftCircle → const IconData
The arrow left circle icon.
arrowLeftSquare → const IconData
The arrow left square icon.
arrowRight → const IconData
The arrow right icon.
arrowRight2 → const IconData
The arrow right 2 icon.
arrowRight3 → const IconData
The arrow right 3 icon.
arrowRightCircle → const IconData
The arrow right circle icon.
arrowRightSquare → const IconData
The arrow right square icon.
arrowUp → const IconData
The arrow up icon.
arrowUp2 → const IconData
The arrow up 2 icon.
arrowUp3 → const IconData
The arrow up 3 icon.
arrowUpCircle → const IconData
The arrow up circle icon.
arrowUpSquare → const IconData
The arrow up square icon.
bag → const IconData
The bag icon.
bag2 → const IconData
The bag 2 icon.
bookmark → const IconData
The bookmark icon.
buy → const IconData
The buy icon.
calendar → const IconData
The calendar icon.
call → const IconData
The call icon.
calling → const IconData
The calling icon.
callMissed → const IconData
The call missed icon.
callSilent → const IconData
The call silent icon.
camera → const IconData
The camera icon.
category → const IconData
The category icon.
chart → const IconData
The chart icon.
chat → const IconData
The chat icon.
closeSquare → const IconData
The close square icon.
danger → const IconData
The danger icon.
delete → const IconData
The delete icon.
discount → const IconData
The discount icon.
discovery → const IconData
The discovery icon.
document → const IconData
The document icon.
download → const IconData
The download icon.
edit → const IconData
The edit icon.
editSquare → const IconData
The edit square icon.
filter → const IconData
The filter icon.
filter2 → const IconData
The filter 2 icon.
folder → const IconData
The folder icon.
game → const IconData
The game icon.
graph → const IconData
The graph icon.
heart → const IconData
The heart icon.
hide → const IconData
The hide icon.
home → const IconData
The home icon.
image → const IconData
The image icon.
image2 → const IconData
The image 2 icon.
infoCircle → const IconData
The info circle icon.
infoSquare → const IconData
The info square icon.
location → const IconData
The location icon.
lock → const IconData
The lock icon.
login → const IconData
The login icon.
logout → const IconData
The logout icon.
message → const IconData
The message icon.
moreCircle → const IconData
The more circle icon.
moreSquare → const IconData
The more square icon.
notification → const IconData
The notification icon.
paper → const IconData
The paper icon.
paperDownload → const IconData
The paper download icon.
paperFail → const IconData
The paper fail icon.
paperNegative → const IconData
The paper negative icon.
paperPlus → const IconData
The paper plus icon.
paperUpload → const IconData
The paper upload icon.
password → const IconData
The password icon.
play → const IconData
The play icon.
plus → const IconData
The plus icon.
profile → const IconData
The profile icon.
scan → const IconData
The scan icon.
The search icon.
send → const IconData
The send icon.
setting → const IconData
The setting icon.
shieldDone → const IconData
The shield done icon.
shieldFail → const IconData
The shield fail icon.
show → const IconData
The show icon.
star → const IconData
The star icon.
swap → const IconData
The swap icon.
ticket → const IconData
The ticket icon.
ticketStar → const IconData
The ticket star icon.
tickSquare → const IconData
The tick square icon.
timeCircle → const IconData
The time circle icon.
timesQuare → const IconData
The time square icon.
unlock → const IconData
The unlock icon.
upload → const IconData
The upload icon.
user2 → const IconData
The user 2 icon.
user3 → const IconData
The user 3 icon.
video → const IconData
The video icon.
voice → const IconData
The voice icon.
voice2 → const IconData
The voice 2 icon.
volumeDown → const IconData
The volume down icon.
volumeOff → const IconData
The volume off icon.
volumeUp → const IconData
The volume up icon.
wallet → const IconData
The wallet icon.
work → const IconData
The work icon.