IconlyLight class
A collection of light styled icons from the Iconly pack.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- activity → const IconData
- The activity icon.
- add_user → const IconData
- The add user icon.
- arrow_down → const IconData
- The arrow down icon.
- arrow_down_2 → const IconData
- The arrow down 2 icon.
- arrow_down_3 → const IconData
- The arrow down 3 icon.
- arrow_down_circle → const IconData
- The arrow down circle icon.
- arrow_down_square → const IconData
- The arrow down square icon.
- arrow_left → const IconData
- The arrow left icon.
- arrow_left_2 → const IconData
- The arrow left 2 icon.
- arrow_left_3 → const IconData
- The arrow left 3 icon.
- arrow_left_circle → const IconData
- The arrow left circle icon.
- arrow_left_square → const IconData
- The arrow left square icon.
- arrow_right → const IconData
- The arrow right icon.
- arrow_right_2 → const IconData
- The arrow right 2 icon.
- arrow_right_3 → const IconData
- The arrow right 3 icon.
- arrow_right_circle → const IconData
- The arrow right circle icon.
- arrow_right_square → const IconData
- The arrow right square icon.
- arrow_up → const IconData
- The arrow up icon.
- arrow_up_2 → const IconData
- The arrow up 2 icon.
- arrow_up_3 → const IconData
- The arrow up 3 icon.
- arrow_up_circle → const IconData
- The arrow up circle icon.
- arrow_up_square → const IconData
- The arrow up square icon.
- bag → const IconData
- The bag icon.
- bag_2 → const IconData
- The bag 2 icon.
- bookmark → const IconData
- The bookmark icon.
- buy → const IconData
- The buy icon.
- calendar → const IconData
- The calendar icon.
- call → const IconData
- The call icon.
- call_missed → const IconData
- The call missed icon.
- call_silent → const IconData
- The call silent icon.
- calling → const IconData
- The calling icon.
- camera → const IconData
- The camera icon.
- category → const IconData
- The category icon.
- chart → const IconData
- The chart icon.
- chat → const IconData
- The chat icon.
- close_square → const IconData
- The close square icon.
- danger → const IconData
- The danger icon.
- delete → const IconData
- The delete icon.
- discount → const IconData
- The discount icon.
- discovery → const IconData
- The discovery icon.
- document → const IconData
- The document icon.
- download → const IconData
- The download icon.
- edit → const IconData
- The edit icon.
- edit_square → const IconData
- The edit square icon.
- filter → const IconData
- The filter icon.
- filter_2 → const IconData
- The filter 2 icon.
- folder → const IconData
- The folder icon.
- game → const IconData
- The game icon.
- graph → const IconData
- The graph icon.
- heart → const IconData
- The heart icon.
- hide → const IconData
- The hide icon.
- home → const IconData
- The home icon.
- image → const IconData
- The image icon.
- image_2 → const IconData
- The image 2 icon.
- info_circle → const IconData
- The info circle icon.
- info_square → const IconData
- The info square icon.
- location → const IconData
- The location icon.
- lock → const IconData
- The lock icon.
- login → const IconData
- The login icon.
- logout → const IconData
- The logout icon.
- message → const IconData
- The message icon.
- more_circle → const IconData
- The more circle icon.
- more_square → const IconData
- The more square icon.
- notification → const IconData
- The notification icon.
- paper → const IconData
- The paper icon.
- paper_download → const IconData
- The paper download icon.
- paper_fail → const IconData
- The paper fail icon.
- paper_negative → const IconData
- The paper negative icon.
- paper_plus → const IconData
- The paper plus icon.
- paper_upload → const IconData
- The paper upload icon.
- password → const IconData
- The password icon.
- play → const IconData
- The play icon.
- plus → const IconData
- The plus icon.
- profile → const IconData
- The profile icon.
- scan → const IconData
- The scan icon.
- search → const IconData
- The search icon.
- send → const IconData
- The send icon.
- setting → const IconData
- The setting icon.
- shield_done → const IconData
- The shield done icon.
- shield_fail → const IconData
- The shield fail icon.
- show → const IconData
- The show icon.
- star → const IconData
- The star icon.
- swap → const IconData
- The swap icon.
- tick_square → const IconData
- The tick square icon.
- ticket → const IconData
- The ticket icon.
- ticket_star → const IconData
- The ticket star icon.
- time_circle → const IconData
- The time circle icon.
- time_square → const IconData
- The time square icon.
- unlock → const IconData
- The unlock icon.
- upload → const IconData
- The upload icon.
- user → const IconData
- The user icon.
- user_1 → const IconData
- The user 1 icon.
- video → const IconData
- The video icon.
- voice → const IconData
- The voice icon.
- voice_2 → const IconData
- The voice 2 icon.
- volume_down → const IconData
- The volume down icon.
- volume_off → const IconData
- The volume off icon.
- volume_up → const IconData
- The volume up icon.
- wallet → const IconData
- The wallet icon.
- work → const IconData
- The work icon.